@@ -1,5 +1,5 @@
 """A pipeline framework for python"""
-from .pipen import Pipen
+from .pipen import Pipen, run
 from .proc import Proc
 from .procgroup import ProcGroup
 
