@@ -8,10 +8,10 @@ from .utils import truncate_text
 if TYPE_CHECKING:  # pragma: no cover
     import enlighten
 
-# [12/02/20 12:44:06] I /main
+# [12/02/20 12:44:06] I core
 #                 pipeline: 100%|
 # |        desc_len      |
-PBAR_DESC_LEN = 23
+PBAR_DESC_LEN = 24
 
 
 class ProcPBar:
@@ -52,7 +52,10 @@ class ProcPBar:
         try:
             self.success_counter.update_from(self.running_counter)
         except ValueError:  # pragma: no cover
-            self.success_counter.update_from(self.submitted_counter)
+            try:
+                self.success_counter.update_from(self.submitted_counter)
+            except ValueError:  # pragma: no cover
+                pass
         except:  # noqa: E722  # pragma: no cover
             pass
 
@@ -61,13 +64,19 @@ class ProcPBar:
         try:
             self.failure_counter.update_from(self.running_counter)
         except ValueError:  # pragma: no cover
-            self.failure_counter.update_from(self.submitted_counter)
+            try:
+                self.failure_counter.update_from(self.submitted_counter)
+            except ValueError:  # pragma: no cover
+                pass
         except:  # noqa: E722  # pragma: no cover
             pass
 
     def done(self):
         """The process is done"""
-        self.submitted_counter.close()
+        try:
+            self.submitted_counter.close()
+        except:  # noqa: E722  # pragma: no cover
+            pass
 
 
 class PipelinePBar:
@@ -118,5 +127,8 @@ class PipelinePBar:
 
     def done(self) -> None:
         """When the pipeline is done"""
-        self.running_counter.close()
-        self.manager.stop()
+        try:
+            self.running_counter.close()
+            self.manager.stop()
+        except:  # noqa: E722  # pragma: no cover
+            pass
